// src/utils/type-helpers.ts
var defineEnum = (value) => value;

// src/constants/default-options.ts
var retryDefaults = defineEnum({
  attempts: 0,
  condition: () => true,
  delay: 1e3,
  maxDelay: 1e4,
  methods: ["GET", "POST"],
  statusCodes: [],
  strategy: "linear"
});
var commonDefaults = defineEnum({
  bodySerializer: JSON.stringify,
  defaultErrorMessage: "An unexpected error occurred during the HTTP request."
});
var responseDefaults = defineEnum({
  responseParser: JSON.parse,
  responseType: "json",
  resultMode: "all"
});
var hookDefaults = defineEnum({
  mergedHooksExecutionMode: "parallel",
  mergedHooksExecutionOrder: "mainHooksAfterPlugins"
});
var dedupeDefaults = defineEnum({
  dedupeStrategy: "cancel"
});
var requestOptionDefaults = defineEnum({
  method: "GET"
});

// src/error.ts
var httpErrorSymbol = Symbol("HTTPError");
var HTTPError = class _HTTPError extends Error {
  errorData;
  httpErrorSymbol = httpErrorSymbol;
  isHTTPError = true;
  name = "HTTPError";
  response;
  constructor(errorDetails, errorOptions) {
    const { defaultErrorMessage, errorData, response } = errorDetails;
    const selectedDefaultErrorMessage = defaultErrorMessage ?? (response.statusText || commonDefaults.defaultErrorMessage);
    const message = errorData?.message ?? selectedDefaultErrorMessage;
    super(message, errorOptions);
    this.errorData = errorData;
    this.response = response;
    Error.captureStackTrace(this, this.constructor);
  }
  /**
   * @description Checks if the given error is an instance of HTTPError
   * @param error - The error to check
   * @returns true if the error is an instance of HTTPError, false otherwise
   */
  static isError(error) {
    if (!isObject(error)) {
      return false;
    }
    if (error instanceof _HTTPError) {
      return true;
    }
    return error.httpErrorSymbol === httpErrorSymbol && error.isHTTPError === true;
  }
};

// src/utils/guards.ts
var isHTTPError = (error) => {
  return isObject(error) && error.name === "HTTPError";
};
var isHTTPErrorInstance = (error) => {
  return HTTPError.isError(error);
};
var isArray = (value) => Array.isArray(value);
var isObject = (value) => {
  return typeof value === "object" && value !== null;
};
var hasObjectPrototype = (value) => {
  return Object.prototype.toString.call(value) === "[object Object]";
};
var isPlainObject = (value) => {
  if (!hasObjectPrototype(value)) {
    return false;
  }
  const constructor = value?.constructor;
  if (constructor === void 0) {
    return true;
  }
  const prototype = constructor.prototype;
  if (!hasObjectPrototype(prototype)) {
    return false;
  }
  if (!Object.hasOwn(prototype, "isPrototypeOf")) {
    return false;
  }
  if (Object.getPrototypeOf(value) !== Object.prototype) {
    return false;
  }
  return true;
};
var isJsonString = (value) => {
  if (!isString(value)) {
    return false;
  }
  try {
    JSON.parse(value);
    return true;
  } catch {
    return false;
  }
};
var isSerializable = (value) => {
  return isPlainObject(value) || isArray(value) || typeof value?.toJSON === "function";
};
var isFunction = (value) => typeof value === "function";
var isQueryString = (value) => isString(value) && value.includes("=");
var isString = (value) => typeof value === "string";
var isReadableStream = (value) => {
  return value instanceof ReadableStream;
};

// src/auth.ts
var getValue = (value) => {
  return isFunction(value) ? value() : value;
};
var getAuthHeader = async (auth) => {
  if (auth === void 0) return;
  if (isString(auth) || auth === null) {
    return { Authorization: `Bearer ${auth}` };
  }
  switch (auth.type) {
    case "Basic": {
      const username = await getValue(auth.username);
      const password = await getValue(auth.password);
      if (username === void 0 || password === void 0) return;
      return {
        Authorization: `Basic ${globalThis.btoa(`${username}:${password}`)}`
      };
    }
    case "Custom": {
      const value = await getValue(auth.value);
      if (value === void 0) return;
      const prefix = await getValue(auth.prefix);
      return {
        Authorization: `${prefix} ${value}`
      };
    }
    default: {
      const bearer = await getValue(auth.bearer);
      const token = await getValue(auth.token);
      if ("token" in auth && token !== void 0) {
        return { Authorization: `Token ${token}` };
      }
      return bearer !== void 0 && { Authorization: `Bearer ${bearer}` };
    }
  }
};

// src/constants/common.ts
var fetchSpecificKeys = defineEnum([
  "body",
  "integrity",
  "duplex",
  "method",
  "headers",
  "signal",
  "cache",
  "redirect",
  "window",
  "credentials",
  "keepalive",
  "referrer",
  "priority",
  "mode",
  "referrerPolicy"
]);

// src/types/common.ts
var optionsEnumToOmitFromBase = defineEnum(["dedupeKey"]);

// src/utils/common.ts
var omitKeys = (initialObject, keysToOmit) => {
  const updatedObject = {};
  const keysToOmitSet = new Set(keysToOmit);
  for (const [key, value] of Object.entries(initialObject)) {
    if (!keysToOmitSet.has(key)) {
      updatedObject[key] = value;
    }
  }
  return updatedObject;
};
var pickKeys = (initialObject, keysToPick) => {
  const updatedObject = {};
  const keysToPickSet = new Set(keysToPick);
  for (const [key, value] of Object.entries(initialObject)) {
    if (keysToPickSet.has(key)) {
      updatedObject[key] = value;
    }
  }
  return updatedObject;
};
var splitBaseConfig = (baseConfig) => [
  pickKeys(baseConfig, fetchSpecificKeys),
  omitKeys(baseConfig, [
    ...fetchSpecificKeys,
    ...optionsEnumToOmitFromBase
  ])
];
var splitConfig = (config) => [
  pickKeys(config, fetchSpecificKeys),
  omitKeys(config, fetchSpecificKeys)
];
var toQueryString = (params) => {
  if (!params) {
    console.error("toQueryString:", "No query params provided!");
    return null;
  }
  return new URLSearchParams(params).toString();
};
var objectifyHeaders = (headers) => {
  if (!headers || isPlainObject(headers)) {
    return headers;
  }
  return Object.fromEntries(headers);
};
var getHeaders = async (options) => {
  const { auth, baseHeaders, body, headers } = options;
  const shouldResolveHeaders = Boolean(baseHeaders || headers || body || auth);
  if (!shouldResolveHeaders) return;
  const headersObject = {
    ...await getAuthHeader(auth),
    ...objectifyHeaders(baseHeaders),
    ...objectifyHeaders(headers)
  };
  if (isQueryString(body)) {
    headersObject["Content-Type"] = "application/x-www-form-urlencoded";
    return headersObject;
  }
  if (isSerializable(body) || isJsonString(body)) {
    headersObject["Content-Type"] = "application/json";
    headersObject.Accept = "application/json";
  }
  return headersObject;
};
var getFetchImpl = (customFetchImpl) => {
  if (customFetchImpl) {
    return customFetchImpl;
  }
  if (typeof globalThis !== "undefined" && isFunction(globalThis.fetch)) {
    return globalThis.fetch;
  }
  throw new Error("No fetch implementation found");
};
var PromiseWithResolvers = () => {
  let reject;
  let resolve;
  const promise = new Promise((res, rej) => {
    resolve = res;
    reject = rej;
  });
  return { promise, reject, resolve };
};
var waitFor = (delay) => {
  if (delay === 0) return;
  const { promise, resolve } = PromiseWithResolvers();
  setTimeout(resolve, delay);
  return promise;
};
var createCombinedSignal = (...signals) => {
  const cleanedSignals = signals.filter(Boolean);
  const combinedSignal = AbortSignal.any(cleanedSignals);
  return combinedSignal;
};
var createTimeoutSignal = (milliseconds) => AbortSignal.timeout(milliseconds);

export { HTTPError, commonDefaults, createCombinedSignal, createTimeoutSignal, dedupeDefaults, getFetchImpl, getHeaders, hookDefaults, isArray, isFunction, isHTTPError, isHTTPErrorInstance, isObject, isPlainObject, isReadableStream, isSerializable, isString, requestOptionDefaults, responseDefaults, retryDefaults, splitBaseConfig, splitConfig, toQueryString, waitFor };
//# sourceMappingURL=chunk-F56CKRKR.js.map
//# sourceMappingURL=chunk-F56CKRKR.js.map